@@ -88,6 +88,8 @@
 #' package before version 3.1.
 #' @param correction Sets whether the correction should be applied (TRUE) or
 #' not (FALSE)
+#' @param verbose Show the parameters and loglikelihood for every call to the
+#' loglik function 
 #' @return \item{lambda_M}{ gives the maximum likelihood estimate of lambda of
 #' the main clade} \item{mu_M}{ gives the maximum likelihood estimate of mu of
 #' the main clade} \item{K_M}{ gives the maximum likelihood estimate of K of
@@ -122,7 +124,27 @@
 #'   optimmethod = 'simplex')
 #' 
 #' @export dd_KI_ML
-dd_KI_ML = function(brtsM, brtsS, tsplit, initparsopt = c(0.5,0.1,2*(1 + length(brtsM) + missnumspec[1]),2*(1 + length(brtsS) + missnumspec[length(missnumspec)]),(tsplit + max(brtsS))/2), parsfix = NULL, idparsopt = c(1:3,6:7), idparsfix = NULL, idparsnoshift = (1:7)[c(-idparsopt,(-1)^(length(idparsfix) != 0) * idparsfix)], res = 10*(1 + length(c(brtsM,brtsS)) + sum(missnumspec)), ddmodel = 1, missnumspec = 0, cond = 1, soc = 2, tol = c(1E-3, 1E-4, 1E-6), maxiter = 1000 * round((1.25)^length(idparsopt)), changeloglikifnoconv = FALSE, optimmethod = 'subplex',num_cycles = 1,methode = 'analytical',correction = FALSE)
+dd_KI_ML = function(brtsM,
+    brtsS,
+    tsplit,
+    initparsopt = c(0.5,0.1,2*(1 + length(brtsM) + missnumspec[1]),2*(1 + length(brtsS) + missnumspec[length(missnumspec)]),(tsplit + max(brtsS))/2),
+    parsfix = NULL,
+    idparsopt = c(1:3,6:7),
+    idparsfix = NULL,
+    idparsnoshift = (1:7)[c(-idparsopt,(-1)^(length(idparsfix) != 0) * idparsfix)],
+    res = 10*(1 + length(c(brtsM,brtsS)) + sum(missnumspec)),
+    ddmodel = 1,
+    missnumspec = 0,
+    cond = 1,
+    soc = 2,
+    tol = c(1E-3, 1E-4, 1E-6),
+    maxiter = 1000 * round((1.25)^length(idparsopt)),
+    changeloglikifnoconv = FALSE,
+    optimmethod = 'subplex',
+    num_cycles = 1,
+    methode = 'analytical',
+    correction = FALSE,
+    verbose = FALSE)
 {
 options(warn = -1)
 brtsM = sort(abs(as.numeric(brtsM)),decreasing = TRUE)
@@ -157,7 +179,7 @@ trparsopt = initparsopt/(1 + initparsopt)
 trparsopt[which(initparsopt == Inf)] = 1
 trparsfix = parsfix/(1 + parsfix)
 trparsfix[which(parsfix == Inf)] = 1
-pars2 = c(res,ddmodel,cond,tsplit,0,soc,correction == TRUE,tol,maxiter)
+pars2 = c(res,ddmodel,cond,tsplit,verbose,soc,correction == TRUE,tol,maxiter)
 optimpars = c(tol,maxiter)
 initloglik = dd_KI_loglik_choosepar(trparsopt = trparsopt,trparsfix = trparsfix,idparsopt = idparsopt,idparsfix = idparsfix,idparsnoshift = idparsnoshift,pars2 = pars2,brtsM = brtsM,brtsS = brtsS,missnumspec = missnumspec,methode = methode)
 cat("The loglikelihood for the initial parameter values is",initloglik,"\n")
