@@ -85,6 +85,8 @@
 #' @param methode The method used in the ode solver, default is ode45
 #' @param correction Sets whether the correction should be applied (TRUE) or
 #' not (FALSE)
+#' @param verbose Show the parameters and loglikelihood for every call to the
+#' loglik function 
 #' @return \item{lambda_M}{ gives the maximum likelihood estimate of lambda of
 #' the main clade} \item{mu_M}{ gives the maximum likelihood estimate of mu of
 #' the main clade} \item{K_M}{ gives the maximum likelihood estimate of K of
@@ -117,7 +119,27 @@
 #'           idparsnoshift = c(4,5), cond = 0, tol = c(3E-1,3E-1,3E-1))
 #' 
 #' @export dd_MS_ML
-dd_MS_ML = function(brtsM, brtsS, tsplit, initparsopt = c(0.5, 0.1, 2 * (1 + length(brtsM) + length(brtsS) + sum(missnumspec)),(tsplit + max(brtsS))/2), parsfix = NULL, idparsopt = c(1:3,6), idparsfix = NULL, idparsnoshift = (1:6)[c(-idparsopt,(-1)^(length(idparsfix) != 0) * idparsfix)], res = 10*(1 + length(c(brtsM,brtsS)) + sum(missnumspec)), ddmodel = 1.3, missnumspec = 0, cond = 0, soc = 2, tol = c(1E-3, 1E-4, 1E-6), maxiter = 1000 * round((1.25)^length(idparsopt)), changeloglikifnoconv = FALSE, optimmethod = 'subplex', num_cycles = 1, methode = 'analytical',correction = FALSE)
+dd_MS_ML = function(brtsM,
+    brtsS,
+    tsplit,
+    initparsopt = c(0.5, 0.1, 2 * (1 + length(brtsM) + length(brtsS) + sum(missnumspec)),(tsplit + max(brtsS))/2),
+    parsfix = NULL,
+    idparsopt = c(1:3,6),
+    idparsfix = NULL,
+    idparsnoshift = (1:6)[c(-idparsopt,(-1)^(length(idparsfix) != 0) * idparsfix)],
+    res = 10*(1 + length(c(brtsM,brtsS)) + sum(missnumspec)),
+    ddmodel = 1.3,
+    missnumspec = 0,
+    cond = 0,
+    soc = 2,
+    tol = c(1E-3, 1E-4, 1E-6),
+    maxiter = 1000 * round((1.25)^length(idparsopt)),
+    changeloglikifnoconv = FALSE,
+    optimmethod = 'subplex',
+    num_cycles = 1,
+    methode = 'analytical',
+    correction = FALSE,
+    verbose = FALSE)
 {
 options(warn = -1)
 brtsM = sort(abs(as.numeric(brtsM)),decreasing = TRUE)
@@ -152,7 +174,7 @@ trparsopt = initparsopt/(1 + initparsopt)
 trparsopt[which(initparsopt == Inf)] = 1
 trparsfix = parsfix/(1 + parsfix)
 trparsfix[which(parsfix == Inf)] = 1
-pars2 = c(res,ddmodel,cond,tsplit,0,soc,correction,tol,maxiter)
+pars2 = c(res,ddmodel,cond,tsplit,verbose,soc,correction,tol,maxiter)
 optimpars = c(tol,maxiter)
 initloglik = dd_MS_loglik_choosepar(trparsopt = trparsopt,trparsfix = trparsfix,idparsopt = idparsopt,idparsfix = idparsfix,idparsnoshift = idparsnoshift,pars2 = pars2,brtsM = brtsM,brtsS = brtsS,missnumspec = missnumspec, methode = methode)
 cat("The loglikelihood for the initial parameter values is",initloglik,"\n")
