@@ -79,6 +79,8 @@
 #' 'analytical' which uses matrix exponentiation; alternatively numerical ODE
 #' solvers can be used, such as 'lsoda' or 'ode45'. These were used in the
 #' package before version 3.1.
+#' @param verbose Show the parameters and loglikelihood for every call to the
+#' loglik function 
 #' @return \item{lambda_1}{ gives the maximum likelihood estimate of lambda
 #' before the shift} \item{mu_1}{ gives the maximum likelihood estimate of mu
 #' before the shift} \item{K_1}{ gives the maximum likelihood estimate of K
@@ -110,7 +112,26 @@
 #' )
 #' 
 #' @export dd_SR_ML
-dd_SR_ML = function(brts, initparsopt = c(0.5,0.1,2*(1+length(brts)+missnumspec),2*(1+length(brts)+missnumspec),max(brts)/2), parsfix = NULL, idparsopt = c(1:3,6:7), idparsfix = NULL, idparsnoshift = (1:7)[c(-idparsopt,(-1)^(length(idparsfix) != 0) * idparsfix)], res = 10*(1 + length(brts) + missnumspec), ddmodel = 1, missnumspec = 0, cond = 1, btorph = 1, soc = 2, allbp = FALSE, tol = c(1E-3, 1E-4, 1E-6), maxiter = 1000 * round((1.25)^length(idparsopt)), changeloglikifnoconv = FALSE, optimmethod = 'subplex', num_cycles = 1, methode = 'analytical')
+dd_SR_ML = function(brts,
+    initparsopt = c(0.5,0.1,2*(1+length(brts)+missnumspec),2*(1+length(brts)+missnumspec),max(brts)/2),
+    parsfix = NULL,
+    idparsopt = c(1:3,6:7),
+    idparsfix = NULL,
+    idparsnoshift = (1:7)[c(-idparsopt,(-1)^(length(idparsfix) != 0) * idparsfix)],
+    res = 10*(1 + length(brts) + missnumspec),
+    ddmodel = 1,
+    missnumspec = 0,
+    cond = 1,
+    btorph = 1,
+    soc = 2,
+    allbp = FALSE,
+    tol = c(1E-3, 1E-4, 1E-6),
+    maxiter = 1000 * round((1.25)^length(idparsopt)),
+    changeloglikifnoconv = FALSE,
+    optimmethod = 'subplex',
+    num_cycles = 1,
+    methode = 'analytical',
+    verbose = FALSE)
 {
 # brts = branching times (positive, from present to past)
 # - max(brts) = crown age
@@ -182,7 +203,7 @@ trparsopt = initparsopt/(1 + initparsopt)
 trparsopt[which(initparsopt == Inf)] = 1
 trparsfix = parsfix/(1 + parsfix)
 trparsfix[which(parsfix == Inf)] = 1
-pars2 = c(res,ddmodel,cond,btorph,0,soc,tol,maxiter)
+pars2 = c(res,ddmodel,cond,btorph,verbose,soc,tol,maxiter)
 optimpars = c(tol,maxiter)
 initloglik = dd_SR_loglik_choosepar(trparsopt = trparsopt,trparsfix = trparsfix,idparsopt = idparsopt,idparsfix = idparsfix,idparsnoshift = idparsnoshift,pars2 = pars2,brts = brts,missnumspec = missnumspec, methode = methode)
 cat("The loglikelihood for the initial parameter values is",initloglik,"\n")
