@@ -6,6 +6,7 @@ mu = pars[2]
 K = pars[3]
 ddep = pars[length(pars)]
 r = (ddep == 5) * pars[4]
+n0 = (ddep == 2 | ddep == 4)
 
 nn = 0:(lx + 1)
 lnn = length(nn)
@@ -17,9 +18,10 @@ if(ddep == 1)
     lavec = pmax(rep(0,lnn),la - (la-mu)/K * nn)
     muvec = mu * rep(1,lnn)
 } else {
-if(ddep == 2)
+if(ddep == 2 | ddep == 2.1 | ddep == 2.2)
 {
-    lavec = pmax(rep(0,lnn),la * (nn + 1)^(-log(la/mu)/log(K+1)))
+    y = -(log(la/mu)/log(K+n0))^(ddep != 2.2)
+    lavec = pmax(rep(0,lnn),la * (nn + n0)^y)
     muvec = mu * rep(1,lnn)
 } else {
 if(ddep == 3)
@@ -27,10 +29,11 @@ if(ddep == 3)
     lavec = la * rep(1,lnn)
     muvec = mu + (la - mu) * nn/K
 } else {
-if(ddep == 4)
+if(ddep == 4 | ddep == 4.1 | ddep == 4.2)
 {
+    y = (log(la/mu)/log(K+n0))^(ddep != 4.2)
     lavec = la * rep(1,lnn)
-    muvec = mu * (nn + 1)^(log(la/mu)/log(K+1))
+    muvec = mu * (nn + n0)^y
 } else {
 if(ddep == 5)
 { 
